@@ -19,9 +19,15 @@
 
 package builtin
 
-import (
-	"github.com/snapcore/snapd/interfaces"
-)
+const cameraSummary = `allows access to all cameras`
+
+const cameraBaseDeclarationSlots = `
+  camera:
+    allow-installation:
+      slot-snap-type:
+        - core
+    deny-auto-connection: true
+`
 
 const cameraConnectedPlugAppArmor = `
 # Until we have proper device assignment, allow access to all cameras
@@ -32,13 +38,18 @@ const cameraConnectedPlugAppArmor = `
 /sys/devices/pci**/usb*/**/idVendor r,
 /sys/devices/pci**/usb*/**/idProduct r,
 /run/udev/data/c81:[0-9]* r, # video4linux (/dev/video*, etc)
+/sys/class/video4linux/ r,
+/sys/devices/pci**/usb*/**/video4linux/** r,
 `
 
-// NewCameraInterface returns a new "camera" interface.
-func NewCameraInterface() interfaces.Interface {
-	return &commonInterface{
-		name: "camera",
+func init() {
+	registerIface(&commonInterface{
+		name:                  "camera",
+		summary:               cameraSummary,
+		implicitOnCore:        true,
+		implicitOnClassic:     true,
+		baseDeclarationSlots:  cameraBaseDeclarationSlots,
 		connectedPlugAppArmor: cameraConnectedPlugAppArmor,
 		reservedForOS:         true,
-	}
+	})
 }
